summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2018-04-08 22:28:19 +0200
committerGitHub <[email protected]>2018-04-08 22:28:19 +0200
commit9e7dedf5af6ea3f70196e86865b8a7e676b419b2 (patch)
treeb7ce38848b492596d1429dd7fcb5d02f3fdc6119 /src/raylib.h
parent3caa044bf259653eadcba5dc413101b95c6ebfbb (diff)
parent7bd0f8b28c4cd576ab5c3e7b696d408f0f8045e4 (diff)
downloadraylib-9e7dedf5af6ea3f70196e86865b8a7e676b419b2.tar.gz
raylib-9e7dedf5af6ea3f70196e86865b8a7e676b419b2.zip
Merge pull request #521 from TheLumaio/master
Added GetCollisionRayModel
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 3986ebcf..a5963905 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -1052,7 +1052,7 @@ RLAPI bool CheckCollisionRaySphere(Ray ray, Vector3 spherePosition, float sphere
RLAPI bool CheckCollisionRaySphereEx(Ray ray, Vector3 spherePosition, float sphereRadius,
Vector3 *collisionPoint); // Detect collision between ray and sphere, returns collision point
RLAPI bool CheckCollisionRayBox(Ray ray, BoundingBox box); // Detect collision between ray and box
-RLAPI RayHitInfo GetCollisionRayMesh(Ray ray, Mesh *mesh); // Get collision info between ray and mesh
+RLAPI RayHitInfo GetCollisionRayModel(Ray ray, Model *model); // Get collision info between ray and model
RLAPI RayHitInfo GetCollisionRayTriangle(Ray ray, Vector3 p1, Vector3 p2, Vector3 p3); // Get collision info between ray and triangle
RLAPI RayHitInfo GetCollisionRayGround(Ray ray, float groundHeight); // Get collision info between ray and ground plane (Y-normal plane)